From 7e48bdf4e952f7b700e64e4cd8cb190bfc630ef9 Mon Sep 17 00:00:00 2001
From: mcramer <m.cramer@pixcept.de>
Date: Wed, 31 Oct 2012 07:42:05 -0400
Subject: [PATCH] Fixed: Follow-up to commit r3623  - entered all missing german and english entries for datalog status  - excluded some more tables from status display  - inserted the info-display code to the relevant templates

---
 interface/web/sites/web_domain_list.php |   23 ++++++++++++-----------
 1 files changed, 12 insertions(+), 11 deletions(-)

diff --git a/interface/web/sites/web_domain_list.php b/interface/web/sites/web_domain_list.php
index edc7e7f..feae9c8 100644
--- a/interface/web/sites/web_domain_list.php
+++ b/interface/web/sites/web_domain_list.php
@@ -41,18 +41,19 @@
 * End Form configuration
 ******************************************/
 
-// Checking module permissions
-if(!stristr($_SESSION["s"]["user"]["modules"],'sites')) {
-	header("Location: ../index.php");
-	exit;
+//* Check permissions for module
+$app->auth->check_module_permissions('sites');
+
+$app->load('listform_actions');
+
+
+class list_action extends listform_actions {
+	
 }
 
-$app->uses('listform_actions');
-
-// Limit the results to alias domains
-// $app->listform_actions->SQLExtWhere = "type = 'local'";
-
-$app->listform_actions->onLoad();
-
+$list = new list_action;
+$list->SQLExtWhere = "type = 'vhost' AND parent_domain_id = '0'";
+$list->SQLOrderBy = 'ORDER BY domain';
+$list->onLoad();
 
 ?>
\ No newline at end of file

--
Gitblit v1.9.1